@@ -4,18 +4,21 @@
 # Licence GPL v3
 
 
-.couldBeLonLat <- function(x) {
-	if (projection(x)=='NA') {
-		e <- extent(x)
-		if (e@xmin > -400 & e@xmax < 400 & e@ymin > -90.1 & e@ymax < 90.1) { 
-			return(TRUE) 
-		} else {
-			return(FALSE)
-		}
-	} else if (isLonLat(x)) { 
-		return(TRUE) 
+.couldBeLonLat <- function(x, warnings=TRUE) {
+	crsLL <- isLonLat(x)
+	crsNA <- projection(x)=='NA'
+	e <- extent(x)
+	extLL <- (e@xmin > -365 & e@xmax < 365 & e@ymin > -90.1 & e@ymax < 90.1) 
+	if (extLL & crsLL) { 
+		return(TRUE)
+	} else if (extLL & crsNA) {
+		if (warnings) warning('CRS is NA. Assuming it is longitude/latitude')
+		return(TRUE)
+	} else if (crsLL) {
+		if (warnings) warning('raster has a longitude/latitude CRS, but coordinates do not match that')
+		return(TRUE)
 	} else {
-		return(FALSE)
+		return(FALSE) 	
 	}
 }
 
