@@ -37,11 +37,12 @@ setExtent <- function(x, bndbox, keepres=FALSE, snap=FALSE) {
 		newobj@extent@xmax <- newobj@extent@xmin + ncol(newobj) * xrs
 		newobj@extent@ymax <- newobj@extent@ymin + nrow(newobj) * yrs
 		
-		if (dataContent(x) == 'all') {
+		if ( inMemory(x) ) {
 			if (ncol(x) == ncol(newobj) & nrow(x) == nrow(newobj)) {
 				newobj <- setValues(newobj, x@data@values)
 			} else {
-				newobj@data@source <- 'ram'
+				newobj@data@fromdisk <- FALSE
+
 				indices <- cellsFromExtent(x, bb, expand=TRUE)
 				v <- vector(length=length(indices))
 				v[] <- NA
@@ -52,7 +53,7 @@ setExtent <- function(x, bndbox, keepres=FALSE, snap=FALSE) {
 		
 	} else if (class(x) != "BasicRaster" & class(x) != "RasterStack") {
 		if (ncol(x)==ncol(newobj) & nrow(x)==nrow(newobj))  {
-			if (dataContent(x) == 'all') {
+			if ( inMemory(x) ) {
 				newobj <- setValues(newobj, x@data@values)
 			}	
 		}
